@@ -179,14 +179,17 @@ public:
 			parent->setUpdatesEnabled(false);
 		}
 
-		auto LayoutItem = m_ParentLayout->takeAt(1);
-		if (LayoutItem)
+		if (m_CurrentWidget)
 		{
-			LayoutItem->widget()->setParent(nullptr);
+			auto LayoutItem = m_ParentLayout->takeAt(1);
+			if (LayoutItem)
+			{
+				LayoutItem->widget()->setParent(nullptr);
+			}
+			delete LayoutItem;
 		}
-		delete LayoutItem;
 
-		m_ParentLayout->addWidget(next);
+		m_ParentLayout->insertWidget(1, next);
 		if (prev)
 		{
 			prev->hide();
@@ -362,6 +365,14 @@ void DockAreaWidgetPrivate::createTitleBar()
 {
 	TitleBar = componentsFactory()->createDockAreaTitleBar(_this);
 	Layout->addWidget(TitleBar);
+	if (CDockManager::testConfigFlag(CDockManager::TabsAtBottom))
+	{
+		// Title bar will be index 0, container widgets will be index 1,
+		// so tabs will always be at the end of the layout.
+		Layout->addWidget(tabBar());
+		tabBar()->setVisible(CDockManager::testConfigFlag(CDockManager::AlwaysShowTabs));
+	}
+
 	QObject::connect(tabBar(), &CDockAreaTabBar::tabCloseRequested, _this, &CDockAreaWidget::onTabCloseRequested);
 	QObject::connect(TitleBar, &CDockAreaTitleBar::tabBarClicked, _this, &CDockAreaWidget::setCurrentIndex);
 	QObject::connect(tabBar(), &CDockAreaTabBar::tabMoved, _this, &CDockAreaWidget::reorderDockWidget);
@@ -726,6 +737,7 @@ void CDockAreaWidget::setCurrentIndex(int index)
     TabBar->setCurrentIndex(index);
 	d->ContentsLayout->setCurrentIndex(index);
 	d->ContentsLayout->currentWidget()->show();
+	d->TitleBar->autoHideTitleLabel()->setText(d->ContentsLayout->currentWidget()->windowTitle());
 	Q_EMIT currentChanged(index);
 }
 
@@ -879,7 +891,22 @@ void CDockAreaWidget::updateTitleBarVisibility()
             {
                 // Always show title bar if it contains title bar actions
                 if (CDockWidget* TopLevelWidget = Container->topLevelDockWidget())
+                {
                     Hidden |= TopLevelWidget->titleBarActions().empty();
+                }
+                else if (CDockManager::testConfigFlag(CDockManager::TabsAtBottom))
+                {
+                    Hidden = true;
+
+                    for (CDockWidget* DockWidget : Container->openedDockWidgets())
+                    {
+                        if (!DockWidget->titleBarActions().empty())
+                        {
+                            Hidden = false;
+                            break;
+                        }
+                    }
+                }
             }
             if (!Hidden && d->Flags.testFlag(HideSingleWidgetTitleBar))
             {
@@ -889,6 +916,8 @@ void CDockAreaWidget::updateTitleBarVisibility()
             }
         }
 		d->TitleBar->setVisible(!Hidden);
+		if (CDockManager::testConfigFlag(CDockManager::TabsAtBottom))
+			d->TitleBar->tabBar()->setVisible(openDockWidgetsCount() > 1);
     }
 
 	if (isAutoHideFeatureEnabled())
